@@ -13,7 +13,7 @@ use Time::ParseDate ();
 
 extends 'Bubblegum::Object::Instance';
 
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
 
 has 'data' => (
     is   => 'ro',
@@ -140,7 +140,7 @@ sub user {
 }
 
 sub user_info {
-    return [(getpwuid $>)];
+    return [eval '(getpwuid $>)'];
 }
 
 sub which {
